package compass;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
import java.sql.*;
import javax.sql.DataSource;
import javax.naming.InitialContext;

/**
 * <h2>Compass travel application</h2>
 * <p>This servlet authenticates a user ID and password
 * using the users table in the compass database.
 * It uses the compass data source, which is defined
 * in the SERVER-INF/jrun-resources.xml file and managed
 * using the JMC.</p>
 */
public class Logon extends HttpServlet {

  private String validLogonPage;
  private String invalidLogonPage;

  /**
   * <p>Reads initialization parameters defined in the web.xml file:</p>
   * <ul>
   * <li>validLogonPage specifies which page to go to if the logon is valid.</li>
   * <li>invalidLogonPage specifies which page to go to if the logon is invalid.</li>
   * </ul>
   * <p>Using this technique, the servlet doesn't require hardcoded page names and the Servlet is more reusable.</p>
   */
  public void init() throws javax.servlet.ServletException {
        validLogonPage = getInitParameter("validLogonPage");
        if (validLogonPage==null) throw new ServletException("web.xml error: init parameter 'validLogonPage' not found");
        invalidLogonPage = getInitParameter("invalidLogonPage");
        if (validLogonPage==null) throw new ServletException("web.xml error: init parameter 'invalidLogonPage' not found");

  }

  /**
   * Authenticates against the user table in the compass database
   * and redirects to the appropriate page.
   *
   * @param HttpServletRequest - Request object
   * @param HttpServletResponse - Response object
   */
  protected void doPost(javax.servlet.http.HttpServletRequest request, javax.servlet.http.HttpServletResponse response)
      throws javax.servlet.ServletException, IOException {

  	String userId = request.getParameter("userId");
	String password = request.getParameter("password");

        String firstName="";
        String lastName="";

	String sql = "SELECT password, first_name, last_name FROM user WHERE user_id=?";
	Connection connection=null;
	PreparedStatement ps=null;
	ResultSet rs=null;
	boolean validLogon=false;

	try {
		InitialContext ctx = new InitialContext();
		DataSource ds = (DataSource) ctx.lookup("java:comp/env/jdbc/compass");
		connection=ds.getConnection();
		ps=connection.prepareStatement(sql);
		ps.setString(1, userId);
		rs = ps.executeQuery();
		if (rs.next()) {
			if (password.equals(rs.getString("password"))) {
                          validLogon=true;
                          firstName=rs.getString("first_name");
                          lastName=rs.getString("last_name");
                        }
		}
	} catch (Exception e) {
		System.out.println(e);
		throw new ServletException(e);
	} finally {
		try {
			rs.close();
			ps.close();
			connection.close();
		} catch (Exception e) {
			System.out.println(e);
		}
	}

	if (validLogon) {
		HttpSession session = request.getSession();
		session.setAttribute("userId", userId);
		session.setAttribute("firstName", firstName);
		session.setAttribute("lastName", lastName);
		response.sendRedirect(validLogonPage);
	} else {
		response.sendRedirect(invalidLogonPage);
	}
  }

}
