package compass;

import javax.naming.*;
import java.sql.*;
import javax.sql.*;
import java.io.*;

/**
 * <h2>Compass travel application</h2>
 * <p>This class ia a JavaBean that compass travel JSPs
 * use to encapsulate information for a trip.</p>
 */
 public class TripBean implements Serializable {

	private int tripId;
	private String name;
	private String image;
	private String description;
	private double price;
	private Date dateStart;
	private Date dateEnd;
	private java.text.NumberFormat nf = java.text.NumberFormat.getCurrencyInstance();

	/**
	 * Sets the trip ID
	 * @param tripId - Trip ID
	 */
	public void setTripId(int tripId) {
		this.tripId=tripId;
		retrieve(tripId);
	}

	/**
	 * Retrieves the trip ID
	 */
	public int getTripId() {
		return tripId;
	}

	/**
	 * Retrieves the trip name
	 */
	public String getName() {
		return name;
	}

	/**
     * Retrieves the filename for the image
     */public String getImage() {
		return image;
	}

	/**
	 * Retrieves the description
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * Retrieves the price
	 */
	public double getPrice() {
		return price;
	}

	/**
	 * Retrieves the price, formatted as currency
	 */
	public String getFormattedPrice( ) {
		return nf.format(price);
	}

	/**
	 * Retrieves the trip start date
	 */
	public Date getDateStart() {
		return dateStart;
	}

	/**
	 * Retrieves the trip end date
	 */
	public Date getDateEnd() {
		return dateEnd;
	}

	/**
	 * Retrieves information for a trip and sets instance fields
	 * with data from the result set.
	 * @param id - Trip ID
	 */
	public void retrieve(int id) {

		String sql="SELECT trip_id, name, image, description, price, date_start, date_end FROM trip WHERE trip_id=?";
		Connection connection=null;
		PreparedStatement ps=null;
		ResultSet rs=null;
		try {
			InitialContext ctx = new InitialContext();
			DataSource ds = (DataSource) ctx.lookup("java:comp/env/jdbc/compass");
			connection=ds.getConnection();
			ps=connection.prepareStatement(sql);
			ps.setInt(1, tripId);
			rs = ps.executeQuery();
			while (rs.next()) {
				name=rs.getString("name");
				image=rs.getString("image");
				description=rs.getString("description");
				price=rs.getDouble("price");
				dateStart=rs.getDate("date_start");
				dateEnd=rs.getDate("date_end");
			}
		} catch (Exception e) {
			System.out.println(e);
		} finally {
			try {
				rs.close();
				ps.close();
				connection.close();
			} catch (Exception e) {
			}
		}
	}
}